==> sugarcrm-5.5.1.tbz: www/sugarcrm/modules/SugarFeed/language/en_us.lang.php <==
<?php
/*********************************************************************************
 * SugarCRM is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2010 SugarCRM Inc.
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 * 
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo. If the display of the logo is not reasonably feasible for
 * technical reasons, the Appropriate Legal Notices must display the words
 * "Powered by SugarCRM".
 ********************************************************************************/
$mod_strings = array (
  'LBL_TEAM' => 'Team',
  'LBL_TEAM_ID' => 'Team Id',
  'LBL_ASSIGNED_TO_ID' => 'Assigned User Id',
  'LBL_ASSIGNED_TO_NAME' => 'Assigned to',
  'LBL_ID' => 'ID',
  'LBL_DATE_ENTERED' => 'Date Created',
  'LBL_DATE_MODIFIED' => 'Date Modified',
  'LBL_MODIFIED' => 'Modified By',
  'LBL_MODIFIED_ID' => 'Modified By Id',
  'LBL_MODIFIED_NAME' => 'Modified By Name',
  'LBL_CREATED' => 'Created By',
  'LBL_CREATED_ID' => 'Created By Id',
  'LBL_DESCRIPTION' => 'Description',
  'LBL_DELETED' => 'Deleted',
  'LBL_NAME' => 'Name',
  'LBL_SAVING'=>'Saving...',
  'LBL_SAVED'=>'Saved',
  'LBL_CREATED_USER' => 'Created by User',
  'LBL_MODIFIED_USER' => 'Modified by User',
  'LBL_LIST_FORM_TITLE' => 'Sugar Feed List',
  'LBL_MODULE_NAME' => 'Sugar Feed',
  'LBL_MODULE_TITLE' => 'Sugar Feed',
  'LBL_DASHLET_DISABLED' => 'Warning: The Sugar Feed system is disabled, no new feed entries will be posted until it is activated',
  'LBL_ADMIN_SETTINGS' => 'Sugar Feed Settings',
  'LBL_RECORDS_DELETED' => 'All previous Sugar Feed entries have been removed, if the Sugar Feed system is enabled, new entries will be generated automatically.',
  'LBL_CONFIRM_DELETE_RECORDS' => 'Are you sure you wish to delete all of the Sugar Feed entries?',
  'LBL_FLUSH_RECORDS' => 'Delete Feed Entries',
  'LBL_ENABLE_FEED' => 'Enable Sugar Feed',
  'LBL_ENABLE_MODULE_LIST' => 'Activate Feeds For',
  'LBL_HOMEPAGE_TITLE' => 'My Sugar Feed',
  'LNK_NEW_RECORD' => 'Create Sugar Feed',
  'LNK_LIST' => 'Sugar Feed',
  'LBL_SEARCH_FORM_TITLE' => 'Search Sugar Feed',
  'LBL_HISTORY_SUBPANEL_TITLE' => 'View History',
  'LBL_ACTIVITIES_SUBPANEL_TITLE' => 'Activities',
  'LBL_SUGAR_FEED_SUBPANEL_TITLE' => 'Sugar Feed',
  'LBL_NEW_FORM_TITLE' => 'New Sugar Feed',
  'LBL_ALL'=>'All',
  'LBL_USER_FEED' => 'User Feed',
  'LBL_ENABLE_USER_FEED' => 'Activate User Feed',
  'LBL_TO'=>'Send To',
  'LBL_IS'=>'is',
  'LBL_DONE'=>'Done',
  'LBL_TITLE'=>'Title',
  'LBL_ROWS'=>'Rows',
  'LBL_CATEGORIES'=>'Modules',
  'LBL_TIME_LAST_WEEK'=>'Last Week',
  'LBL_TIME_WEEKS'    =>'Weeks',
  'LBL_TIME_DAYS'     =>'Days',
  'LBL_TIME_YESTERDAY'=>'Yesterday',
  'LBL_TIME_HOURS'    =>'Hours',
  'LBL_TIME_HOUR'     =>'Hours',
  'LBL_TIME_MINUTES'  =>'Minutes',
  'LBL_TIME_MINUTE'   =>'Minute',
  'LBL_TIME_SECONDS'  =>'Seconds',
  'LBL_TIME_SECOND'   =>'Second',
  'LBL_TIME_AGO'      =>'ago',

  'CREATED_CONTACT'=>'created a <b>NEW</b> contact',
  'CREATED_OPPORTUNITY'=>'created a <b>NEW</b> opportunity',
  'CREATED_CASE'=>'created a <b>NEW</b> case',
  'CREATED_LEAD'=>'created a <b>NEW</b> lead',
  'FOR'=>'for',
  'CLOSED_CASE'=>'<b>CLOSED</b> a case ',
  'CONVERTED_LEAD'=>'<b>CONVERTED</b> a lead',
  'WON_OPPORTUNITY'=>'has <b>WON</b> an opportunity',
  'WITH' => 'with',

  'LBL_LINK_TYPE_Link' => 'Link',
  'LBL_LINK_TYPE_Image' => 'Image',
  'LBL_LINK_TYPE_YouTube' => 'YouTube&#153;',
  
  'LBL_SELECT' => 'Select',  
  'LBL_POST' => 'Post', 
);
?>

==> sugarcrm-6.2.1.tbz: www/sugarcrm/modules/SugarFeed/language/en_us.lang.php <==
<?php
/*********************************************************************************
 * SugarCRM Community Edition is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2011 SugarCRM Inc.
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 * 
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU Affero General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo. If the display of the logo is not reasonably feasible for
 * technical reasons, the Appropriate Legal Notices must display the words
 * "Powered by SugarCRM".
 ********************************************************************************/

$mod_strings = array (
  'LBL_TEAM' => 'Team',
  'LBL_TEAM_ID' => 'Team Id',
  'LBL_ASSIGNED_TO_ID' => 'Assigned User Id',
  'LBL_ASSIGNED_TO_NAME' => 'Assigned to',
  'LBL_ID' => 'ID',
  'LBL_DATE_ENTERED' => 'Date Created',
  'LBL_DATE_MODIFIED' => 'Date Modified',
  'LBL_MODIFIED' => 'Modified By',
  'LBL_MODIFIED_ID' => 'Modified By Id',
  'LBL_MODIFIED_NAME' => 'Modified By Name',
  'LBL_CREATED' => 'Created By',
  'LBL_CREATED_ID' => 'Created By Id',
  'LBL_DESCRIPTION' => 'Description',
  'LBL_DELETED' => 'Deleted',
  'LBL_NAME' => 'Name',
  'LBL_SAVING'=>'Saving...',
  'LBL_SAVED'=>'Saved',
  'LBL_CREATED_USER' => 'Created by User',
  'LBL_MODIFIED_USER' => 'Modified by User',
  'LBL_LIST_FORM_TITLE' => 'Feed List',
  'LBL_MODULE_NAME' => 'Activity Streams',
  'LBL_MODULE_TITLE' => 'Activity Streams',
  'LBL_DASHLET_DISABLED' => 'Warning: The Feed system is disabled, no new feed entries will be posted until it is activated',
  'LBL_ADMIN_SETTINGS' => 'Feed Settings',
  'LBL_RECORDS_DELETED' => 'All previous Feed entries have been removed, if the Feed system is enabled, new entries will be generated automatically.',
  'LBL_CONFIRM_DELETE_RECORDS' => 'Are you sure you wish to delete all of the Feed entries?',
  'LBL_FLUSH_RECORDS' => 'Delete Feed Entries',
  'LBL_ENABLE_FEED' => 'Enable My Activity Stream Dashlet',
  'LBL_ENABLE_MODULE_LIST' => 'Activate Feeds For',
  'LBL_HOMEPAGE_TITLE' => 'My Activity Stream',
  'LNK_NEW_RECORD' => 'Create Feed',
  'LNK_LIST' => 'Feed',
  'LBL_SEARCH_FORM_TITLE' => 'Search Feed',
  'LBL_HISTORY_SUBPANEL_TITLE' => 'View History',
  'LBL_ACTIVITIES_SUBPANEL_TITLE' => 'Activities',
  'LBL_SUGAR_FEED_SUBPANEL_TITLE' => 'Feed',
  'LBL_NEW_FORM_TITLE' => 'New Feed',
  'LBL_ALL'=>'All',
  'LBL_USER_FEED' => 'User Feed',
  'LBL_ENABLE_USER_FEED' => 'Activate User Feed',
  'LBL_TO'=>'Visible to Team',
  'LBL_IS'=>'is',
  'LBL_DONE'=>'Done',
  'LBL_TITLE'=>'Title',
  'LBL_ROWS'=>'Rows',
  'LBL_CATEGORIES'=>'Modules',
  'LBL_TIME_LAST_WEEK'=>'Last Week',
  'LBL_TIME_WEEKS'    =>'Weeks',
  'LBL_TIME_DAYS'     =>'Days',
  'LBL_TIME_YESTERDAY'=>'Yesterday',
  'LBL_TIME_HOURS'    =>'Hours',
  'LBL_TIME_HOUR'     =>'Hours',
  'LBL_TIME_MINUTES'  =>'Minutes',
  'LBL_TIME_MINUTE'   =>'Minute',
  'LBL_TIME_SECONDS'  =>'Seconds',
  'LBL_TIME_SECOND'   =>'Second',
  'LBL_TIME_AGO'      =>'ago',

  'CREATED_CONTACT'=>'created a <b>NEW</b> contact',
  'CREATED_OPPORTUNITY'=>'created a <b>NEW</b> opportunity',
  'CREATED_CASE'=>'created a <b>NEW</b> case',
  'CREATED_LEAD'=>'created a <b>NEW</b> lead',
  'FOR'=>'for',
  'CLOSED_CASE'=>'<b>CLOSED</b> a case ',
  'CONVERTED_LEAD'=>'<b>CONVERTED</b> a lead',
  'WON_OPPORTUNITY'=>'has <b>WON</b> an opportunity',
  'WITH' => 'with',

  'LBL_LINK_TYPE_Link' => 'Link',
  'LBL_LINK_TYPE_Image' => 'Image',
  'LBL_LINK_TYPE_YouTube' => 'YouTube&#153;',
  
  'LBL_SELECT' => 'Select',  
  'LBL_POST' => 'Post', 
  'LBL_EXTERNAL_PREFIX' => 'External: ',
  'LBL_EXTERNAL_WARNING' => 'Items labeled "external" require an <a href="?module=EAPM">external account</a>.',
  'LBL_AUTHENTICATE' => 'Connect to',
  'LBL_AUTHENTICATION_PENDING' => 'Not all of the external accounts you have selected have been authenticated. Click \'Cancel\' to return to the Options window to authenticate the external accounts, or click \'Ok\' to proceed without authenticating.',
);
?>
